@@ -1,4 +1,5 @@
 import time
+from typing import Mapping
 
 from celery import Celery
 from celery import __version__ as celery_version
@@ -15,10 +16,10 @@ def before_publish(*args, properties={}, **kwargs):
     properties["published_at"] = time.time()
 
 
-def judoscale_celery(celery: Celery, extra_config: dict = {}) -> None:
+def judoscale_celery(celery: Celery, extra_config: Mapping = {}) -> None:
     celery.conf.task_send_sent_event = True
 
-    judoconfig.merge(extra_config)
+    judoconfig.update(extra_config)
     collector = CeleryMetricsCollector(config=judoconfig, broker=celery)
     adapter = Adapter(
         identifier="judoscale-celery",
